@@ -15,19 +15,20 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 """This module allows to connect to a MySQL database."""
+from __future__ import annotations
+
 import json
-from typing import TYPE_CHECKING, Dict, Optional, Tuple, Union
+from typing import TYPE_CHECKING, Any, Union
 
-from airflow.hooks.dbapi import DbApiHook
 from airflow.models import Connection
+from airflow.providers.common.sql.hooks.sql import DbApiHook
 
 if TYPE_CHECKING:
     from mysql.connector.abstracts import MySQLConnectionAbstract
     from MySQLdb.connections import Connection as MySQLdbConnection
 
-MySQLConnectionTypes = Union['MySQLdbConnection', 'MySQLConnectionAbstract']
+MySQLConnectionTypes = Union["MySQLdbConnection", "MySQLConnectionAbstract"]
 
 
 class MySqlHook(DbApiHook):
@@ -48,10 +49,10 @@ class MySqlHook(DbApiHook):
     :param connection: The :ref:`MySQL connection id <howto/connection:mysql>` used for MySQL credentials.
     """
 
-    conn_name_attr = 'mysql_conn_id'
-    default_conn_name = 'mysql_default'
-    conn_type = 'mysql'
-    hook_name = 'MySQL'
+    conn_name_attr = "mysql_conn_id"
+    default_conn_name = "mysql_default"
+    conn_type = "mysql"
+    hook_name = "MySQL"
     supports_autocommit = True
 
     def __init__(self, *args, **kwargs) -> None:
@@ -61,91 +62,95 @@ class MySqlHook(DbApiHook):
 
     def set_autocommit(self, conn: MySQLConnectionTypes, autocommit: bool) -> None:
         """
-        The MySQLdb (mysqlclient) client uses an `autocommit` method rather
-        than an `autocommit` property to set the autocommit setting
+        Set *autocommit*.
+
+        *mysqlclient* uses an *autocommit* method rather than an *autocommit*
+        property, so we need to override this to support it.
 
         :param conn: connection to set autocommit setting
         :param autocommit: autocommit setting
-        :rtype: None
         """
-        if hasattr(conn.__class__, 'autocommit') and isinstance(conn.__class__.autocommit, property):
+        if hasattr(conn.__class__, "autocommit") and isinstance(conn.__class__.autocommit, property):
             conn.autocommit = autocommit
         else:
             conn.autocommit(autocommit)
 
     def get_autocommit(self, conn: MySQLConnectionTypes) -> bool:
         """
-        The MySQLdb (mysqlclient) client uses a `get_autocommit` method
-        rather than an `autocommit` property to get the autocommit setting
+        Whether *autocommit* is active.
+
+        *mysqlclient* uses an *get_autocommit* method rather than an *autocommit*
+        property, so we need to override this to support it.
 
         :param conn: connection to get autocommit setting from.
         :return: connection autocommit setting
-        :rtype: bool
         """
-        if hasattr(conn.__class__, 'autocommit') and isinstance(conn.__class__.autocommit, property):
+        if hasattr(conn.__class__, "autocommit") and isinstance(conn.__class__.autocommit, property):
             return conn.autocommit
         else:
             return conn.get_autocommit()
 
-    def _get_conn_config_mysql_client(self, conn: Connection) -> Dict:
+    def _get_conn_config_mysql_client(self, conn: Connection) -> dict:
         conn_config = {
             "user": conn.login,
-            "passwd": conn.password or '',
-            "host": conn.host or 'localhost',
-            "db": self.schema or conn.schema or '',
+            "passwd": conn.password or "",
+            "host": conn.host or "localhost",
+            "db": self.schema or conn.schema or "",
         }
 
         # check for authentication via AWS IAM
-        if conn.extra_dejson.get('iam', False):
-            conn_config['passwd'], conn.port = self.get_iam_token(conn)
-            conn_config["read_default_group"] = 'enable-cleartext-plugin'
+        if conn.extra_dejson.get("iam", False):
+            conn_config["passwd"], conn.port = self.get_iam_token(conn)
+            conn_config["read_default_group"] = "enable-cleartext-plugin"
 
         conn_config["port"] = int(conn.port) if conn.port else 3306
 
-        if conn.extra_dejson.get('charset', False):
+        if conn.extra_dejson.get("charset", False):
             conn_config["charset"] = conn.extra_dejson["charset"]
-            if conn_config["charset"].lower() in ('utf8', 'utf-8'):
+            if conn_config["charset"].lower() in ("utf8", "utf-8"):
                 conn_config["use_unicode"] = True
-        if conn.extra_dejson.get('cursor', False):
+        if conn.extra_dejson.get("cursor", False):
             import MySQLdb.cursors
 
-            if (conn.extra_dejson["cursor"]).lower() == 'sscursor':
+            if (conn.extra_dejson["cursor"]).lower() == "sscursor":
                 conn_config["cursorclass"] = MySQLdb.cursors.SSCursor
-            elif (conn.extra_dejson["cursor"]).lower() == 'dictcursor':
+            elif (conn.extra_dejson["cursor"]).lower() == "dictcursor":
                 conn_config["cursorclass"] = MySQLdb.cursors.DictCursor
-            elif (conn.extra_dejson["cursor"]).lower() == 'ssdictcursor':
+            elif (conn.extra_dejson["cursor"]).lower() == "ssdictcursor":
                 conn_config["cursorclass"] = MySQLdb.cursors.SSDictCursor
-        local_infile = conn.extra_dejson.get('local_infile', False)
-        if conn.extra_dejson.get('ssl', False):
+        local_infile = conn.extra_dejson.get("local_infile", False)
+        if conn.extra_dejson.get("ssl", False):
             # SSL parameter for MySQL has to be a dictionary and in case
             # of extra/dejson we can get string if extra is passed via
             # URL parameters
-            dejson_ssl = conn.extra_dejson['ssl']
+            dejson_ssl = conn.extra_dejson["ssl"]
             if isinstance(dejson_ssl, str):
                 dejson_ssl = json.loads(dejson_ssl)
-            conn_config['ssl'] = dejson_ssl
-        if conn.extra_dejson.get('unix_socket'):
-            conn_config['unix_socket'] = conn.extra_dejson['unix_socket']
+            conn_config["ssl"] = dejson_ssl
+        if conn.extra_dejson.get("unix_socket"):
+            conn_config["unix_socket"] = conn.extra_dejson["unix_socket"]
         if local_infile:
             conn_config["local_infile"] = 1
         return conn_config
 
-    def _get_conn_config_mysql_connector_python(self, conn: Connection) -> Dict:
+    def _get_conn_config_mysql_connector_python(self, conn: Connection) -> dict:
         conn_config = {
-            'user': conn.login,
-            'password': conn.password or '',
-            'host': conn.host or 'localhost',
-            'database': self.schema or conn.schema or '',
-            'port': int(conn.port) if conn.port else 3306,
+            "user": conn.login,
+            "password": conn.password or "",
+            "host": conn.host or "localhost",
+            "database": self.schema or conn.schema or "",
+            "port": int(conn.port) if conn.port else 3306,
         }
 
-        if conn.extra_dejson.get('allow_local_infile', False):
+        if conn.extra_dejson.get("allow_local_infile", False):
             conn_config["allow_local_infile"] = True
 
         return conn_config
 
     def get_conn(self) -> MySQLConnectionTypes:
         """
+        Connection to a MySQL database.
+
         Establishes a connection to a mysql database
         by extracting the connection configuration from the Airflow connection.
 
@@ -157,32 +162,24 @@ class MySqlHook(DbApiHook):
         """
         conn = self.connection or self.get_connection(getattr(self, self.conn_name_attr))
 
-        client_name = conn.extra_dejson.get('client', 'mysqlclient')
+        client_name = conn.extra_dejson.get("client", "mysqlclient")
 
-        if client_name == 'mysqlclient':
+        if client_name == "mysqlclient":
             import MySQLdb
 
             conn_config = self._get_conn_config_mysql_client(conn)
             return MySQLdb.connect(**conn_config)
 
-        if client_name == 'mysql-connector-python':
+        if client_name == "mysql-connector-python":
             import mysql.connector
 
             conn_config = self._get_conn_config_mysql_connector_python(conn)
             return mysql.connector.connect(**conn_config)
 
-        raise ValueError('Unknown MySQL client name provided!')
-
-    def get_uri(self) -> str:
-        conn = self.get_connection(getattr(self, self.conn_name_attr))
-        uri = super().get_uri()
-        if conn.extra_dejson.get('charset', False):
-            charset = conn.extra_dejson["charset"]
-            return f"{uri}?charset={charset}"
-        return uri
+        raise ValueError("Unknown MySQL client name provided!")
 
     def bulk_load(self, table: str, tmp_file: str) -> None:
-        """Loads a tab-delimited file into a database table"""
+        """Load a tab-delimited file into a database table."""
         conn = self.get_conn()
         cur = conn.cursor()
         cur.execute(
@@ -192,9 +189,10 @@ class MySqlHook(DbApiHook):
             """
         )
         conn.commit()
+        conn.close()
 
     def bulk_dump(self, table: str, tmp_file: str) -> None:
-        """Dumps a database table into a tab-delimited file"""
+        """Dump a database table into a tab-delimited file."""
         conn = self.get_conn()
         cur = conn.cursor()
         cur.execute(
@@ -204,29 +202,33 @@ class MySqlHook(DbApiHook):
             """
         )
         conn.commit()
+        conn.close()
 
     @staticmethod
-    def _serialize_cell(cell: object, conn: Optional[Connection] = None) -> object:
+    def _serialize_cell(cell: object, conn: Connection | None = None) -> Any:
         """
+        Convert argument to a literal.
+
         The package MySQLdb converts an argument to a literal
         when passing those separately to execute. Hence, this method does nothing.
 
         :param cell: The cell to insert into the table
         :param conn: The database connection
         :return: The same cell
-        :rtype: object
         """
         return cell
 
-    def get_iam_token(self, conn: Connection) -> Tuple[str, int]:
+    def get_iam_token(self, conn: Connection) -> tuple[str, int]:
         """
+        Retrieve a temporary password to connect to MySQL.
+
         Uses AWSHook to retrieve a temporary password to connect to MySQL
         Port is required. If none is provided, default 3306 is used
         """
         from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
 
-        aws_conn_id = conn.extra_dejson.get('aws_conn_id', 'aws_default')
-        aws_hook = AwsBaseHook(aws_conn_id, client_type='rds')
+        aws_conn_id = conn.extra_dejson.get("aws_conn_id", "aws_default")
+        aws_hook = AwsBaseHook(aws_conn_id, client_type="rds")
         if conn.port is None:
             port = 3306
         else:
@@ -236,7 +238,7 @@ class MySqlHook(DbApiHook):
         return token, port
 
     def bulk_load_custom(
-        self, table: str, tmp_file: str, duplicate_key_handling: str = 'IGNORE', extra_options: str = ''
+        self, table: str, tmp_file: str, duplicate_key_handling: str = "IGNORE", extra_options: str = ""
     ) -> None:
         """
         A more configurable way to load local data from a file into the database.
@@ -271,3 +273,4 @@ class MySqlHook(DbApiHook):
 
         cursor.close()
         conn.commit()
+        conn.close()
